@@ -1,9 +1,6 @@
 package Crypt::Random::Source;
-BEGIN {
-  $Crypt::Random::Source::AUTHORITY = 'cpan:NUFFIN';
-}
-# git description: v0.07-12-g69cb5f2
-$Crypt::Random::Source::VERSION = '0.08';
+# git description: v0.08-7-g993a4e9
+$Crypt::Random::Source::VERSION = '0.09';
 # ABSTRACT: Get weak or strong random data from pluggable sources
 
 use strict;
@@ -49,7 +46,7 @@ Crypt::Random::Source - Get weak or strong random data from pluggable sources
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -98,27 +95,25 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Florian Ragwitz David Pottage Max Kanat-Alexander
+
 =over 4
 
 =item *
 
-David Pottage <spudsoup@cpan.org>
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
 Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Max Kanat-Alexander <mkanat@es-compy.(none)>
+Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Yuval Kogman <nothingmuch@woobling.org>
+David Pottage <spudsoup@cpan.org>
+
+=item *
+
+Max Kanat-Alexander <mkanat@es-compy.(none)>
 
 =back
 
