@@ -1,13 +1,8 @@
 package Crypt::Random::Source::Base;
-BEGIN {
-  $Crypt::Random::Source::Base::AUTHORITY = 'cpan:NUFFIN';
-}
-BEGIN {
-  $Crypt::Random::Source::Base::VERSION = '0.06';
-}
 # ABSTRACT: Abstract base class for L<Crypt::Random::Source> classes
-
+$Crypt::Random::Source::Base::VERSION = '0.09';
 use Any::Moose;
+use namespace::autoclean;
 
 sub available { 0 }
 
@@ -19,48 +14,50 @@ sub get { die "abstract" }
 
 # cannibalized from IO::Scalar
 sub read {
-	my $self = $_[0];
-	my $n    = $_[2];
-	my $off  = $_[3] || 0;
+    my $self = $_[0];
+    my $n    = $_[2];
+    my $off  = $_[3] || 0;
 
-	my $read = $self->get($n);
-	$n = length($read);
-	($off ? substr($_[1], $off) : $_[1]) = $read;
-	return $n;
+    my $read = $self->get($n);
+    $n = length($read);
+    ($off ? substr($_[1], $off) : $_[1]) = $read;
+    return $n;
 }
 
 sub get_data {
-	my ( $self, %params ) = @_;
+    my ( $self, %params ) = @_;
 
-	if ( my $n = $params{Length} ) {
-		return $self->get($n);
-	} else {
-		my $size = $params{Size};
+    if ( my $n = $params{Length} ) {
+        return $self->get($n);
+    } else {
+        my $size = $params{Size};
 
-		if (ref $size && ref $size eq "Math::Pari") {
-			$size = Math::Pari::pari2num($size);
-		}
+        if (ref $size && ref $size eq "Math::Pari") {
+            $size = Math::Pari::pari2num($size);
+        }
 
-		return $self->get( int($size / 8) + 1 );
-	}
+        return $self->get( int($size / 8) + 1 );
+    }
 }
 
 1;
 
-
-__END__
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Crypt::Random::Source::Base - Abstract base class for L<Crypt::Random::Source> classes
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
-	use Moose;
-	extends qw(Crypt::Random::Source::Base);
+    use Moose;
+    extends qw(Crypt::Random::Source::Base);
 
 =head1 DESCRIPTION
 
@@ -110,14 +107,18 @@ Provided for compatibility with L<Crypt::Random>
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@woobling.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman.
+This software is copyright (c) 2008 by Yuval Kogman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+__END__
+
+
+# ex: set sw=4 et:
