@@ -1,12 +1,6 @@
 package Crypt::Random::Source::Base::File;
-BEGIN {
-  $Crypt::Random::Source::Base::File::AUTHORITY = 'cpan:NUFFIN';
-}
-BEGIN {
-  $Crypt::Random::Source::Base::File::VERSION = '0.07';
-}
 # ABSTRACT: File (or device) random data sources
-
+$Crypt::Random::Source::Base::File::VERSION = '0.09';
 use Any::Moose;
 
 use Carp qw(croak);
@@ -14,6 +8,7 @@ use Carp qw(croak);
 extends qw(Crypt::Random::Source::Base::Handle);
 
 use IO::File;
+use namespace::autoclean;
 
 has path => (
     is => "rw",
@@ -35,19 +30,18 @@ sub open_handle {
 
 1;
 
-
-# ex: set sw=4 et:
-
-
-__END__
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Crypt::Random::Source::Base::File - File (or device) random data sources
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
     use Moose;
@@ -75,14 +69,18 @@ Uses L<IO::File> to open C<path> for reading.
 
 =head1 AUTHOR
 
-  Yuval Kogman <nothingmuch@woobling.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yuval Kogman.
+This software is copyright (c) 2008 by Yuval Kogman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+__END__
+
+
+# ex: set sw=4 et:
