@@ -1,30 +1,25 @@
 package Crypt::Random::Source::Strong;
-BEGIN {
-  $Crypt::Random::Source::Strong::AUTHORITY = 'cpan:NUFFIN';
-}
-BEGIN {
-  $Crypt::Random::Source::Strong::VERSION = '0.07';
-}
 # ABSTRACT: Abstract base class for strong random data sources
-
+$Crypt::Random::Source::Strong::VERSION = '0.09';
 use Any::Moose;
+use namespace::autoclean;
 
 sub is_strong { 1 }
 
 1;
 
-
-# ex: set sw=4 et:
-
-__END__
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Crypt::Random::Source::Strong - Abstract base class for strong random data sources
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
     use Moose;
@@ -43,14 +38,18 @@ Returns true
 
 =head1 AUTHOR
 
-  Yuval Kogman <nothingmuch@woobling.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yuval Kogman.
+This software is copyright (c) 2008 by Yuval Kogman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+__END__
+
+
+# ex: set sw=4 et:
